signals
==================================================
**Module**: :mod:`espressodb.base.signals`

.. currentmodule:: espressodb.base.signals

.. autosummary::
   base_save_handler
   base_m2m_add_handler

------

.. automodule:: espressodb.base.signals
    :members:
    :special-members:
